AXIsProcessTrusted

Function AXIsProcessTrusted 

pub unsafe extern "C-unwind" fn AXIsProcessTrusted() -> bool
Available on crate features AXUIElement and HIServices only.
Returns whether the current process is a trusted accessibility client.

Returns: Returns TRUE if the current process is a trusted accessibility client, FALSE if it is not.