AXError

Struct AXError 

#[repr(transparent)]
pub struct AXError(pub i32);
Available on crate features AXError and HIServices only.
Error codes returned by accessibility functions.

See also Apple’s documentation

Tuple Fields

0: i32

Implementations

Source

impl AXError

pub const Success: Self

No error occurred.

pub const Failure: Self

A system error occurred, such as the failure to allocate an object.

pub const IllegalArgument: Self

An illegal argument was passed to the function.

pub const InvalidUIElement: Self

The AXUIElementRef passed to the function is invalid.

pub const InvalidUIElementObserver: Self

The AXObserverRef passed to the function is not a valid observer.

pub const CannotComplete: Self

The function cannot complete because messaging failed in some way or because the application with which the function is communicating is busy or unresponsive.

pub const AttributeUnsupported: Self

The attribute is not supported by the AXUIElementRef.

pub const ActionUnsupported: Self

The action is not supported by the AXUIElementRef.

pub const NotificationUnsupported: Self

The notification is not supported by the AXUIElementRef.

pub const NotImplemented: Self

Indicates that the function or method is not implemented (this can be returned if a process does not support the accessibility API).

pub const NotificationAlreadyRegistered: Self

This notification has already been registered for.

pub const NotificationNotRegistered: Self

Indicates that a notification is not registered yet.

pub const APIDisabled: Self

The accessibility API is disabled (as when, for example, the user deselects “Enable access for assistive devices” in Universal Access Preferences).

pub const NoValue: Self

The requested value or AXUIElementRef does not exist.

pub const ParameterizedAttributeUnsupported: Self

The parameterized attribute is not supported by the AXUIElementRef.

pub const NotEnoughPrecision: Self

Not enough precision.