pub struct AXTextMarker { /* private fields */ }AXUIElement and HIServices only.Expand description
An AXTextMarkerRef is a CFType. Like all CFTypes, they are reference counted (
//apple_ref/c/func/CFRetain CFRetain,
//apple_ref/c/func/CFRelease CFRelease).
See also Apple’s documentation
Implementations
Sourceimpl AXTextMarker
impl AXTextMarker
Sourcepub unsafe fn new(
allocator: Option<&CFAllocator>,
bytes: NonNull<u8>,
length: CFIndex,
) -> CFRetained<AXTextMarker>
pub unsafe fn new( allocator: Option<&CFAllocator>, bytes: NonNull<u8>, length: CFIndex, ) -> CFRetained<AXTextMarker>
Creates a new text marker.
Parameter bytes: The data used to identify this location in text
Parameter length: The length of the data
Safety
bytes must be a valid pointer.
Methods from Deref<Target = CFType>
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: ConcreteType,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: ConcreteType,
Attempt to downcast the type to that of type T.
This is the reference-variant. Use CFRetained::downcast if you
want to convert a retained type. See also ConcreteType for more
details on which types support being converted to.
Sourcepub fn retain_count(&self) -> usize
pub fn retain_count(&self) -> usize
Get the reference count of the object.
This function may be useful for debugging. You normally do not use this function otherwise.
Beware that some things (like CFNumbers, small CFStrings etc.) may
not have a normal retain count for optimization purposes, and can
return usize::MAX in that case.