AXValue

Struct AXValue 

pub struct AXValue { /* private fields */ }
Available on crate features AXValue and HIServices only.
Implementations

Source

impl AXValue

pub unsafe fn new( the_type: AXValueType, value_ptr: NonNull<c_void>, ) -> Option<CFRetained<AXValue>>

Encodes a structure pointed to by valuePtr into a CFTypeRef.

Parameter theType: Parameter valuePtr: Returns:

Safety

value_ptr must be a valid pointer.

pub unsafe fn type(&self) -> AXValueType

Returns the structure type encoded in value. If the type is not recognized, it returns kAXValueIllegalType.

Parameter value: Returns:

pub unsafe fn value( &self, the_type: AXValueType, value_ptr: NonNull<c_void>, ) -> bool

Decodes the structure stored in value and copies it into valuePtr. If the structure stored in value is not the same as requested by theType, the function returns false.

Parameter value: Returns:

Safety

value_ptr must be a valid pointer.

Methods from Deref<Target = CFType>

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: ConcreteType,

Attempt to downcast the type to that of type T.

This is the reference-variant. Use CFRetained::downcast if you want to convert a retained type. See also ConcreteType for more details on which types support being converted to.

pub fn retain_count(&self) -> usize

Get the reference count of the object.

This function may be useful for debugging. You normally do not use this function otherwise.

Beware that some things (like CFNumbers, small CFStrings etc.) may not have a normal retain count for optimization purposes, and can return usize::MAX in that case.