HIMutableShape

Struct HIMutableShape 

pub struct HIMutableShape { /* private fields */ }
Available on crate features HIServices and HIShape only.
Implementations

Source

impl HIMutableShape

pub unsafe fn new() -> Option<CFRetained<HIMutableShape>>

pub unsafe fn new_copy(in_orig: &HIShape) -> Option<CFRetained<HIMutableShape>>

pub unsafe fn with_rect( in_rect: *const CGRect, ) -> Option<CFRetained<HIMutableShape>>

Safety

in_rect must be a valid pointer.

pub unsafe fn set_empty(in_shape: Option<&HIMutableShape>) -> u32

Safety

in_shape might not allow None.

pub unsafe fn set_with_shape( in_dest_shape: Option<&HIMutableShape>, in_src_shape: Option<&HIShape>, ) -> u32

Safety
  • in_dest_shape might not allow None.
  • in_src_shape might not allow None.
Source

impl HIMutableShape

pub unsafe fn offset( in_shape: Option<&HIMutableShape>, in_dx: CGFloat, in_dy: CGFloat, ) -> u32

Safety

in_shape might not allow None.

pub unsafe fn inset( in_shape: Option<&HIMutableShape>, in_dx: CGFloat, in_dy: CGFloat, ) -> u32

Safety

in_shape might not allow None.

pub unsafe fn union_with_rect( in_shape: Option<&HIMutableShape>, in_rect: *const CGRect, ) -> u32

Safety
  • in_shape might not allow None.
  • in_rect must be a valid pointer.

Methods from Deref<Target = HIShape>

pub unsafe fn copy(&self) -> Option<CFRetained<HIShape>>

pub unsafe fn intersection( &self, in_shape2: Option<&HIShape>, ) -> Option<CFRetained<HIShape>>

Safety

in_shape2 might not allow None.

pub unsafe fn create_difference( &self, in_shape2: Option<&HIShape>, ) -> Option<CFRetained<HIShape>>

Safety

in_shape2 might not allow None.

pub unsafe fn create_union( &self, in_shape2: Option<&HIShape>, ) -> Option<CFRetained<HIShape>>

Safety

in_shape2 might not allow None.

pub unsafe fn create_xor( &self, in_shape2: Option<&HIShape>, ) -> Option<CFRetained<HIShape>>

Safety

in_shape2 might not allow None.

pub unsafe fn is_empty(&self) -> bool

pub unsafe fn is_rectangular(&self) -> bool

pub unsafe fn contains_point(&self, in_point: *const CGPoint) -> bool

Safety

in_point must be a valid pointer.

pub unsafe fn intersects_rect(&self, in_rect: *const CGRect) -> bool

Safety

in_rect must be a valid pointer.

pub unsafe fn bounds(&self, out_rect: *mut CGRect) -> *mut CGRect

Safety

out_rect must be a valid pointer.

pub unsafe fn replace_path_in_cg_context( &self, in_context: Option<&CGContext>, ) -> u32

Available on crate feature objc2-core-graphics only.
Safety

in_context might not allow None.

pub unsafe fn enumerate( &self, in_options: u32, in_proc: HIShapeEnumerateProcPtr, in_refcon: *mut c_void, ) -> u32

Safety
  • in_proc must be implemented correctly.
  • in_refcon must be a valid pointer.
pub unsafe fn intersect( &self, in_shape2: Option<&HIShape>, out_result: Option<&HIMutableShape>, ) -> u32

Safety
  • in_shape2 might not allow None.
  • out_result might not allow None.
pub unsafe fn difference( &self, in_shape2: Option<&HIShape>, out_result: Option<&HIMutableShape>, ) -> u32

Safety
  • in_shape2 might not allow None.
  • out_result might not allow None.
pub unsafe fn union( &self, in_shape2: Option<&HIShape>, out_result: Option<&HIMutableShape>, ) -> u32

Safety
  • in_shape2 might not allow None.
  • out_result might not allow None.
pub unsafe fn xor( &self, in_shape2: Option<&HIShape>, out_result: Option<&HIMutableShape>, ) -> u32

Safety
  • in_shape2 might not allow None.
  • out_result might not allow None.

Methods from Deref<Target = CFType>

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: ConcreteType,

Attempt to downcast the type to that of type T.

This is the reference-variant. Use CFRetained::downcast if you want to convert a retained type. See also ConcreteType for more details on which types support being converted to.

pub fn retain_count(&self) -> usize

Get the reference count of the object.

This function may be useful for debugging. You normally do not use this function otherwise.

Beware that some things (like CFNumbers, small CFStrings etc.) may not have a normal retain count for optimization purposes, and can return usize::MAX in that case.