#[repr(transparent)]pub struct AXError(pub i32);AXError and HIServices only.Expand description
Error codes returned by accessibility functions.
See also Apple’s documentation
Tuple Fields
0: i32Implementations
Sourceimpl AXError
impl AXError
Sourcepub const IllegalArgument: Self
pub const IllegalArgument: Self
An illegal argument was passed to the function.
Sourcepub const InvalidUIElement: Self
pub const InvalidUIElement: Self
The AXUIElementRef passed to the function is invalid.
Sourcepub const InvalidUIElementObserver: Self
pub const InvalidUIElementObserver: Self
The AXObserverRef passed to the function is not a valid observer.
Sourcepub const CannotComplete: Self
pub const CannotComplete: Self
The function cannot complete because messaging failed in some way or because the application with which the function is communicating is busy or unresponsive.
Sourcepub const AttributeUnsupported: Self
pub const AttributeUnsupported: Self
The attribute is not supported by the AXUIElementRef.
Sourcepub const ActionUnsupported: Self
pub const ActionUnsupported: Self
The action is not supported by the AXUIElementRef.
Sourcepub const NotificationUnsupported: Self
pub const NotificationUnsupported: Self
The notification is not supported by the AXUIElementRef.
Sourcepub const NotImplemented: Self
pub const NotImplemented: Self
Indicates that the function or method is not implemented (this can be returned if a process does not support the accessibility API).
Sourcepub const NotificationAlreadyRegistered: Self
pub const NotificationAlreadyRegistered: Self
This notification has already been registered for.
Sourcepub const NotificationNotRegistered: Self
pub const NotificationNotRegistered: Self
Indicates that a notification is not registered yet.
Sourcepub const APIDisabled: Self
pub const APIDisabled: Self
The accessibility API is disabled (as when, for example, the user deselects “Enable access for assistive devices” in Universal Access Preferences).
Sourcepub const ParameterizedAttributeUnsupported: Self
pub const ParameterizedAttributeUnsupported: Self
The parameterized attribute is not supported by the AXUIElementRef.
Sourcepub const NotEnoughPrecision: Self
pub const NotEnoughPrecision: Self
Not enough precision.